<?php

namespace Drupal\qtools_common;

use Drupal\views\Views;

/**
 * Class QToolsViewsHelper.
 *
 * @package Drupal\qtools
 */
abstract class QToolsViewsHelper {

  /**
   * Get view's output.
   */
  public static function getViewContent($name, $args = [], $exposed = [], $items_per_page = FALSE, $display_id = 'default') {
    // Load view object.
    $view = Views::getView($name);

    if (empty($view)) {
      return [];
    }

    // Set arguments and exposed input.
    if (!empty($args)) {
      $view->setArguments($args);
    }

    if (!empty($exposed)) {
      $view->setExposedInput($exposed);
    }

    // Set items per page.
    if ($items_per_page !== FALSE) {

      // If items per page is array
      // consider first item as offset.
      if (is_array($items_per_page)) {
        $view->setOffset($items_per_page[0]);
        $view->setItemsPerPage($items_per_page[1]);
      }
      else {
        $view->setItemsPerPage($items_per_page);
      }
    }

    if (is_string($display_id)) {
      $view->setDisplay($display_id);
    }
    else {
      $view->initDisplay();
    }

    return $view->render();

  }

  /**
   * Get view's result from input parameters.
   *
   * @return array
   *   Views result array
   */
  public static function getViewResult($name, $args = [], $exposed = [], $items_per_page = FALSE, $display_id = 'default') {

    // Load view object.
    $view = Views::getView($name);

    if (empty($view)) {
      return [];
    }

    // Set arguments and exposed input.
    if (!empty($args)) {
      $view->setArguments($args);
    }

    if (!empty($exposed)) {
      $view->setExposedInput($exposed);
    }

    // Set items per page.
    if ($items_per_page !== FALSE) {

      // If items per page is array
      // consider first item as offset.
      if (is_array($items_per_page)) {
        $view->setOffset($items_per_page[0]);
        $view->setItemsPerPage($items_per_page[1]);
      }
      else {
        $view->setItemsPerPage($items_per_page);
      }
    }

    if (is_string($display_id)) {
      $view->setDisplay($display_id);
    }
    else {
      $view->initDisplay();
    }

    $view->preExecute();
    $view->execute();
    $result = $view->result;
    $view->destroy();

    return $result;
  }

}
