<?php

namespace Drupal\qtools_common\Utility;

use Drupal\qtools_common\QToolsConfigHelper;

/**
 * Provides trait services configuration management with overrides.
 *
 * if service uses this trait, it it must implements
 * "QToolsConfigurableServiceInterface" and be tagged with
 *  tags:
 *   - { name: qtools_configurable_service }
 */
trait QToolsConfigTrait {

  /**
   * Gets config value.
   *
   * @param $key
   * @return mixed
   * @throws \Exception
   */
  public function config($key) {
    $defaults = static::getConfigTraitDefaults();
    $bundle = static::getConfigTraitBundle();

    // Check if this key exists among defaults.
    if (!array_key_exists($key, $defaults)) {
      $error = t('Config key [@key] not found in defaults for [@name].', [
        '@key' => $key,
        '@name' => $bundle,
      ]);
      throw new \Exception($error);
    }

    return QToolsConfigHelper::get($bundle . '][' . $key);
  }



}
