<?php

namespace Drupal\qtools_common\Utility;

/**
 * Provides helper to debug.
 *
 * @ingroup utility
 */
class QToolsDebug {

  /**
   * Checks for recursion and die after some amount of invocations.
   */
  public static function dieAt($die_count = 1) {
    $count = &drupal_static('QToolsDebug:stopAt', 0);
    $count++;

    if ($count >= $die_count) {
      $func = 'die';
      $func('died on ' . $die_count);
    }
  }

  /**
   * Prints debug message taking into account place it was called.
   */
  public static function log($data = 'called', $name = '', $call_step = 1) {
    // Get called class name.
    $bt = debug_backtrace(DEBUG_BACKTRACE_IGNORE_ARGS);
    $call = $bt[$call_step];
    $name .= ($call['class'] ?? '') . ($call['type'] ?? '') . $call['function'] . '( ' . $bt[$call_step - 1]['line'] . ' )';
    $logger = 'dpm';
    if (function_exists($logger)) {
      $logger($data, $name);
    }
  }

  /**
   * Starts/measures timer and return its key.
   */
  public static function timer($key = NULL, $log = TRUE, $call_stops = 2) {
    $timers = &drupal_static('QToolsDebug:timers', []);

    // Create new timer if no key passed.
    if ($key === NULL) {
      $key = uniqid(TRUE);
      $timers[$key] = microtime(TRUE);
      return $key;
    }
    else {
      // Return elapsed time on given timer.
      $elapsed = microtime(TRUE) - $timers[$key];
      if ($log) {
        static::log($elapsed, $log, $call_stops);
      }
      return $elapsed;
    }
  }

}
